@@ -1,17 +1,16 @@
 use strict;
 use warnings;
 package Dist::Zilla::App;
-BEGIN {
-  $Dist::Zilla::App::VERSION = '4.101900';
+{
+  $Dist::Zilla::App::VERSION = '4.300005';
 }
 # ABSTRACT: Dist::Zilla's App::Cmd
-use App::Cmd::Setup 0.307 -app; # need ->app in Result of Tester, GLD vers
+use App::Cmd::Setup 0.309 -app; # better compilation error detection
 
 use Carp ();
 use Dist::Zilla::MVP::Reader::Finder;
 use Dist::Zilla::Util;
 use Moose::Autobox;
-use Path::Class;
 use Try::Tiny;
 
 sub global_opt_spec {
@@ -108,10 +107,17 @@ sub zilla {
 
     my $core_debug = grep { m/\A[-_]\z/ } @v_plugins;
 
-    my $zilla = Dist::Zilla::Dist::Builder->from_config({
-      chrome => $self->chrome,
-      _global_stashes => $self->_build_global_stashes,
-    });
+    my $zilla;
+    try {
+      $zilla = Dist::Zilla::Dist::Builder->from_config({
+        chrome => $self->chrome,
+        _global_stashes => $self->_build_global_stashes,
+      });
+    } catch {
+      die $_ unless try { $_->isa('Config::MVP::Error') }
+                 && $_->ident =~ /no viable config/;
+      $self->chrome->logger->log_fatal("no configuration (e.g, dist.ini) found");
+    };
 
     $zilla->logger->set_debug($verbose ? 1 : 0);
 
@@ -140,7 +146,7 @@ Dist::Zilla::App - Dist::Zilla's App::Cmd
 
 =head1 VERSION
 
-version 4.101900
+version 4.300005
 
 =head1 METHODS
 
@@ -155,7 +161,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
