@@ -1,6 +1,6 @@
 package Dist::Zilla::Chrome::Term;
-BEGIN {
-  $Dist::Zilla::Chrome::Term::VERSION = '4.200000';
+{
+  $Dist::Zilla::Chrome::Term::VERSION = '4.300005';
 }
 use Moose;
 # ABSTRACT: chrome used for terminal-based interaction
@@ -8,9 +8,8 @@ use Moose;
 
 use Dist::Zilla::Types qw(OneZero);
 use Log::Dispatchouli 1.102220;
-use Term::ReadLine;
-use Term::ReadKey;
-use Term::UI;
+
+use namespace::autoclean;
 
 has logger => (
   is  => 'ro',
@@ -32,21 +31,35 @@ has term_ui => (
   is   => 'ro',
   isa  => 'Object',
   lazy => 1,
-  default => sub { Term::ReadLine->new('dzil') },
+  default => sub {
+    require Term::ReadLine;
+    require Term::UI;
+    Term::ReadLine->new('dzil')
+  },
 );
 
+sub decode_utf8 ($;$)
+{
+    require Encode;
+    no warnings 'redefine';
+    *decode_utf8 = \&Encode::decode_utf8;
+    goto \&decode_utf8;
+}
+
+
 sub prompt_str {
   my ($self, $prompt, $arg) = @_;
   $arg ||= {};
   my $default = $arg->{default};
   my $check   = $arg->{check};
 
-  my $input = $self->term_ui->get_reply(
+  my $input_bytes = $self->term_ui->get_reply(
     prompt => $prompt,
     allow  => $check || sub { defined $_[0] and length $_[0] },
     (defined $default ? (default => $default) : ()),
   );
 
+  my $input = decode_utf8( $input_bytes );
   chomp $input;
 
   return $input;
@@ -74,14 +87,18 @@ sub prompt_any_key {
   if ($isa_tty) {
     local $| = 1;
     print $prompt;
-    Term::ReadKey::ReadMode 'cbreak';
+
+    require Term::ReadKey;
+    Term::ReadKey::ReadMode('cbreak');
     Term::ReadKey::ReadKey(0);
-    Term::ReadKey::ReadMode 'normal';
+    Term::ReadKey::ReadMode('normal');
     print "\n";
   }
 }
 
 with 'Dist::Zilla::Role::Chrome';
+
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -93,7 +110,7 @@ Dist::Zilla::Chrome::Term - chrome used for terminal-based interaction
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 OVERVIEW
 
@@ -106,7 +123,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
