@@ -1,11 +1,13 @@
 package Dist::Zilla::MVP::Assembler::Zilla;
-BEGIN {
-  $Dist::Zilla::MVP::Assembler::Zilla::VERSION = '4.200000';
+{
+  $Dist::Zilla::MVP::Assembler::Zilla::VERSION = '4.300005';
 }
 use Moose;
 extends 'Dist::Zilla::MVP::Assembler';
 # ABSTRACT: Dist::Zilla::MVP::Assembler for the Dist::Zilla object
 
+use namespace::autoclean;
+
 
 use MooseX::Types::Perl qw(PackageName);
 use Dist::Zilla::MVP::RootSection;
@@ -39,7 +41,7 @@ sub register_stash {
   return;
 }
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -51,7 +53,7 @@ Dist::Zilla::MVP::Assembler::Zilla - Dist::Zilla::MVP::Assembler for the Dist::Z
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 OVERVIEW
 
@@ -86,7 +88,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
