@@ -1,16 +1,16 @@
 package Dist::Zilla::MintingProfile::Default;
-BEGIN {
-  $Dist::Zilla::MintingProfile::Default::VERSION = '4.200000';
+{
+  $Dist::Zilla::MintingProfile::Default::VERSION = '4.300005';
 }
 # ABSTRACT: Default minting profile provider
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 
+use namespace::autoclean;
+
 use Dist::Zilla::Util;
 use Path::Class;
 
-use namespace::autoclean;
-
 
 around profile_dir => sub {
   my ($orig, $self, $profile_name) = @_;
@@ -25,6 +25,7 @@ around profile_dir => sub {
   return $self->$orig($profile_name);
 };
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -36,7 +37,7 @@ Dist::Zilla::MintingProfile::Default - Default minting profile provider
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -51,7 +52,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
