@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::AutoVersion;
-BEGIN {
-  $Dist::Zilla::Plugin::AutoVersion::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::AutoVersion::VERSION = '4.300005';
 }
 # ABSTRACT: take care of numbering versions so you don't have to
 use Moose;
@@ -9,6 +9,8 @@ with(
   'Dist::Zilla::Role::TextTemplate',
 );
 
+use namespace::autoclean;
+
 use DateTime 0.44 (); # CLDR fixes
 
 
@@ -56,7 +58,6 @@ sub provide_version {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -68,7 +69,7 @@ Dist::Zilla::Plugin::AutoVersion - take care of numbering versions so you don't
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -104,7 +105,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
