@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::DistINI;
-BEGIN {
-  $Dist::Zilla::Plugin::DistINI::VERSION = '4.200009';
+{
+  $Dist::Zilla::Plugin::DistINI::VERSION = '4.300005';
 }
 # ABSTRACT: a plugin to add a dist.ini to newly-minted dists
 use Moose;
@@ -69,7 +69,6 @@ sub gather_files {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -81,7 +80,7 @@ Dist::Zilla::Plugin::DistINI - a plugin to add a dist.ini to newly-minted dists
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 DESCRIPTION
 
