@@ -1,11 +1,13 @@
 package Dist::Zilla::Plugin::ExtraTests;
-BEGIN {
-  $Dist::Zilla::Plugin::ExtraTests::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::ExtraTests::VERSION = '4.300005';
 }
 # ABSTRACT: rewrite ./xt tests to ./t tests with skips
 use Moose;
 with 'Dist::Zilla::Role::FileMunger';
 
+use namespace::autoclean;
+
 
 sub munge_file {
   my ($self, $file) = @_;
@@ -55,7 +57,6 @@ BEGIN {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -67,7 +68,7 @@ Dist::Zilla::Plugin::ExtraTests - rewrite ./xt tests to ./t tests with skips
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -87,7 +88,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
