@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GatherDir;
-BEGIN {
-  $Dist::Zilla::Plugin::GatherDir::VERSION = '4.200009';
+{
+  $Dist::Zilla::Plugin::GatherDir::VERSION = '4.300005';
 }
 # ABSTRACT: gather all the files in a directory
 use Moose;
@@ -8,6 +8,8 @@ use Moose::Autobox;
 use MooseX::Types::Path::Class qw(Dir File);
 with 'Dist::Zilla::Role::FileGatherer';
 
+use namespace::autoclean;
+
 
 use File::Find::Rule;
 use File::HomeDir;
@@ -47,6 +49,22 @@ has follow_symlinks => (
   default => 0,
 );
 
+sub mvp_multivalue_args { qw(exclude_filename exclude_match) }
+
+
+has exclude_filename => (
+  is   => 'ro',
+  isa  => 'ArrayRef',
+  default => sub { [] },
+);
+
+
+has exclude_match => (
+  is   => 'ro',
+  isa  => 'ArrayRef',
+  default => sub { [] },
+);
+
 sub gather_files {
   my ($self) = @_;
 
@@ -58,12 +76,21 @@ sub gather_files {
   my $rule = File::Find::Rule->new();
   $rule->extras({follow => $self->follow_symlinks});
   FILE: for my $filename ($rule->file->in($root)) {
+    my $file = file($filename)->relative($root);
+
     unless ($self->include_dotfiles) {
-      my $file = file($filename)->relative($root);
       next FILE if $file->basename =~ qr/^\./;
       next FILE if grep { /^\.[^.]/ } $file->dir->dir_list;
     }
 
+    my $exclude_regex = qr/\000/;
+    $exclude_regex = qr/$exclude_regex|$_/
+      for ($self->exclude_match->flatten);
+    # \b\Q$_\E\b should also handle the `eq` check
+    $exclude_regex = qr/$exclude_regex|\b\Q$_\E\b/
+      for ($self->exclude_filename->flatten);
+    next if $file =~ $exclude_regex;
+
     push @files, $self->_file_from_filename($filename);
   }
 
@@ -89,7 +116,6 @@ sub _file_from_filename {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -101,7 +127,7 @@ Dist::Zilla::Plugin::GatherDir - gather all the files in a directory
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -154,6 +180,17 @@ By default, directories that are symlinks will not be followed. Note on the
 other hand that in all followed directories, files which are symlinks are
 always gathered.
 
+=head2 exclude_filename
+
+To exclude certain files from being gathered, use the C<exclude_filename>
+option. This may be used multiple times to specify multiple files to exclude.
+
+=head2 exclude_match
+
+This is just like C<exclude_filename> but provides a regular expression
+pattern.  Files matching the pattern are not gathered.  This may be used
+multiple times to specify multiple patterns to exclude.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
