@@ -1,11 +1,13 @@
 package Dist::Zilla::Plugin::MetaConfig;
-BEGIN {
-  $Dist::Zilla::Plugin::MetaConfig::VERSION = '4.101612';
+{
+  $Dist::Zilla::Plugin::MetaConfig::VERSION = '4.300005';
 }
 # ABSTRACT: summarize Dist::Zilla configuration into distmeta
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
+use namespace::autoclean;
+
 
 sub metadata {
   my ($self) = @_;
@@ -36,8 +38,7 @@ sub metadata {
   return { x_Dist_Zilla => $dump };
 }
 
-no Moose;
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -49,7 +50,7 @@ Dist::Zilla::Plugin::MetaConfig - summarize Dist::Zilla configuration into distm
 
 =head1 VERSION
 
-version 4.101612
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -62,11 +63,11 @@ more data to this dump.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
