@@ -1,12 +1,14 @@
 package Dist::Zilla::Plugin::MetaNoIndex;
-BEGIN {
-  $Dist::Zilla::Plugin::MetaNoIndex::VERSION = '4.200009';
+{
+  $Dist::Zilla::Plugin::MetaNoIndex::VERSION = '4.300005';
 }
 # ABSTRACT: Stop CPAN from indexing stuff
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
+use namespace::autoclean;
+
 
 my %ATTR_ALIAS = (
   directories => [ qw(directory dir folder) ],
@@ -51,7 +53,6 @@ sub metadata {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -63,7 +64,7 @@ Dist::Zilla::Plugin::MetaNoIndex - Stop CPAN from indexing stuff
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 SYNOPSIS
 
