@@ -1,16 +1,18 @@
 package Dist::Zilla::Plugin::ModuleBuild;
-BEGIN {
-  $Dist::Zilla::Plugin::ModuleBuild::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::ModuleBuild::VERSION = '4.300005';
 }
 # ABSTRACT: build a Build.PL that uses Module::Build
 use List::MoreUtils qw(any uniq);
 use Moose;
 use Moose::Autobox;
-with 'Dist::Zilla::Role::BuildRunner';
-with 'Dist::Zilla::Role::PrereqSource';
-with 'Dist::Zilla::Role::InstallTool';
-with 'Dist::Zilla::Role::TextTemplate';
-with 'Dist::Zilla::Role::TestRunner';
+with (
+  'Dist::Zilla::Role::BuildPL',
+  'Dist::Zilla::Role::PrereqSource',
+  'Dist::Zilla::Role::TextTemplate',
+);
+
+use namespace::autoclean;
 
 use Dist::Zilla::File::InMemory;
 use List::MoreUtils qw(any uniq);
@@ -123,6 +125,7 @@ sub setup_installer {
   );
   $module_build_dumper->Sortkeys( 1 );
   $module_build_dumper->Indent( 1 );
+  $module_build_dumper->Useqq( 1 );
 
   my $content = $self->fill_in_string(
     $template,
@@ -147,26 +150,7 @@ has __module_build_args => (
   isa  => 'HashRef',
 );
 
-sub build {
-  my $self = shift;
-
-  system($^X => 'Build.PL') and die "error with Build.PL\n";
-  system($^X, 'Build')      and die "error running $^X Build\n";
-
-  return;
-}
-
-sub test {
-  my ($self, $target) = @_;
-
-  $self->build;
-  system($^X, 'Build', 'test') and die "error running $^X Build test\n";
-
-  return;
-}
-
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -178,7 +162,7 @@ Dist::Zilla::Plugin::ModuleBuild - build a Build.PL that uses Module::Build
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -205,7 +189,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
