@@ -1,14 +1,15 @@
 package Dist::Zilla::Plugin::PodSyntaxTests;
-BEGIN {
-  $Dist::Zilla::Plugin::PodSyntaxTests::VERSION = '4.200009';
+{
+  $Dist::Zilla::Plugin::PodSyntaxTests::VERSION = '4.300005';
 }
 # ABSTRACT: a release test for Pod syntax
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
 
+use namespace::autoclean;
+
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 
@@ -21,7 +22,7 @@ Dist::Zilla::Plugin::PodSyntaxTests - a release test for Pod syntax
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 DESCRIPTION
 
