@@ -1,11 +1,13 @@
 package Dist::Zilla::Plugin::Prereq;
-BEGIN {
-  $Dist::Zilla::Plugin::Prereq::VERSION = '4.200009';
+{
+  $Dist::Zilla::Plugin::Prereq::VERSION = '4.300005';
 }
 # ABSTRACT: (DEPRECATED) the old name of the Prereqs plugin
 use Moose;
 extends 'Dist::Zilla::Plugin::Prereqs';
 
+use namespace::autoclean;
+
 
 before register_component => sub {
   die "[Prereq] is incompatible with Dist::Zilla >= v5; replace it with [Prereqs] (note the
@@ -14,7 +16,6 @@ before register_component => sub {
   warn "!!! [Prereq] will be removed in Dist::Zilla v5; replace it with [Prereqs] (note the 's')\n";
 };
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -27,7 +28,7 @@ Dist::Zilla::Plugin::Prereq - (DEPRECATED) the old name of the Prereqs plugin
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 SYNOPSIS
 
