@@ -1,40 +1,20 @@
 package Dist::Zilla::Plugin::Prereqs;
-BEGIN {
-  $Dist::Zilla::Plugin::Prereqs::VERSION = '4.200009';
+{
+  $Dist::Zilla::Plugin::Prereqs::VERSION = '4.300005';
 }
 # ABSTRACT: list simple prerequisites
 use Moose;
 with 'Dist::Zilla::Role::PrereqSource';
 
+use namespace::autoclean;
 
-sub __from_name {
-  my ($self) = @_;
-  my $name = $self->plugin_name;
-
-  # such as C<configure>, C<build>, C<test> and C<runtime>.  Values are
-  # relationship such as C<requires>, C<prefers>, or C<recommends>.  The
-  # phase component is optional and will default to Runtime.
-
-  my ($phase, $type) = $name =~ /\A
-    (Build|Test|Runtime|Configure|Develop)?
-    (Requires|Recommends|Suggests|Conflicts)
-  \z/x;
-
-  return ($phase, $type);
-}
 
 has prereq_phase => (
   is   => 'ro',
   isa  => 'Str',
   lazy => 1,
   init_arg => 'phase',
-  default  => sub {
-    my ($self) = @_;
-    my ($phase, $type) = $self->__from_name;
-    $phase ||= 'runtime';
-    $phase = lc $phase;
-    return $phase;
-  },
+  default  => 'runtime',
 );
 
 has prereq_type => (
@@ -42,13 +22,7 @@ has prereq_type => (
   isa  => 'Str',
   lazy => 1,
   init_arg => 'type',
-  default  => sub {
-    my ($self) = @_;
-    my ($phase, $type) = $self->__from_name;
-    $type ||= 'requires';
-    $type = lc $type;
-    return $type;
-  },
+  default  => 'requires',
 );
 
 around dump_config => sub {
@@ -71,6 +45,8 @@ has _prereq => (
   default => sub { {} },
 );
 
+sub mvp_aliases { return { -relationship => '-type' } }
+
 sub BUILDARGS {
   my ($class, @arg) = @_;
   my %copy = ref $arg[0] ? %{$arg[0]} : @arg;
@@ -89,6 +65,25 @@ sub BUILDARGS {
 
   confess "don't try to pass -_prereq as a build arg!" if $other{_prereq};
 
+  # Handle magic plugin names:
+  unless (($other{phase} and $other{type})
+          or $name =~ m! (?: \A | / ) Prereqs? \z !x) {
+
+    my ($phase, $type) = $name =~ /\A
+      (Build|Test|Runtime|Configure|Develop)?
+      (Requires|Recommends|Suggests|Conflicts)
+    \z/x;
+
+    if ($type) {
+      $other{phase} ||= lc $phase if defined $phase;
+      $other{type}  ||= lc $type;
+    } else {
+      $zilla->chrome->logger->log_fatal({ prefix => "[$name] " },
+                                      "No -phase or -relationship specified")
+        unless $other{phase} or $other{type};
+    }
+  }
+
   return {
     zilla => $zilla,
     plugin_name => $name,
@@ -109,7 +104,6 @@ sub register_prereqs {
   );
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -122,7 +116,7 @@ Dist::Zilla::Plugin::Prereqs - list simple prerequisites
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 SYNOPSIS
 
@@ -133,15 +127,38 @@ In your F<dist.ini>:
   MRO::Compat = 10
   Sub::Exporter = 0
 
-Which is equivalent to specifying prerequisites for the C<Runtime>
-phase:
+You can specify requirements for different phases and relationships with:
 
-  [Prereqs / RuntimeRequires]
-  Foo::Bar = 1.002
-  MRO::Compat = 10
-  Sub::Exporter = 0
+  [Prereqs]
+  -phase = test
+  -relationship = recommends
 
-See L</Phases> for the full list of supported phases.
+  Fitz::Fotz    = 1.23
+  Text::SoundEx = 3
+
+Remember that if you load two Prereqs plugins, each will needs its own name,
+added like this:
+
+  [Prereqs / PluginName]
+  -phase = test
+  -relationship = recommends
+
+  Fitz::Fotz    = 1.23
+  Text::SoundEx = 3
+
+If the name is the CamelCase concatenation of a phase and relationship
+(or just a relationship), it will set those parameters implicitly.  If
+you use a custom name, but it does not specify the relationship, and
+you didn't specify either C<-phase> or C<-relationship>, it throws the
+error C<No -phase or -relationship specified>.  This is to prevent a
+typo that makes the name meaningless from slipping by unnoticed.
+
+The example below is equivalent to the example above, except for the name of
+the resulting plugin:
+
+  [Prereqs / TestRecommends]
+  Fitz::Fotz    = 1.23
+  Text::SoundEx = 3
 
 =head1 DESCRIPTION
 
