@@ -1,14 +1,19 @@
 package Dist::Zilla::Plugin::TemplateModule;
-BEGIN {
-  $Dist::Zilla::Plugin::TemplateModule::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::TemplateModule::VERSION = '4.300005';
 }
 # ABSTRACT: a simple module-from-template plugin
 use Moose;
 with qw(Dist::Zilla::Role::ModuleMaker Dist::Zilla::Role::TextTemplate);
 
+use namespace::autoclean;
+
 use autodie;
 
-use Data::Section 0.004 -setup; # fixed header_re
+use Sub::Exporter::ForMethods;
+use Data::Section 0.004 # fixed header_re
+  { installer => Sub::Exporter::ForMethods::method_installer },
+  '-setup';
 use Dist::Zilla::File::InMemory;
 
 
@@ -52,7 +57,6 @@ sub make_module {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 
@@ -64,7 +68,7 @@ Dist::Zilla::Plugin::TemplateModule - a simple module-from-template plugin
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -88,7 +92,26 @@ By default, the template looks something like this:
 =head2 template
 
 The C<template> parameter may be given to the plugin to provide a different
-filename, absolute or relative to the build root.
+filename, absolute or relative to the build/profile directory.
+
+If this parameter is not specified, this module will use the boilerplate module
+template included in this module.
+
+=head1 MINTING CONFIGURATION
+
+This module is part of the standard configuration of the default L<Dist::Zilla>
+Minting Profile, and all profiles that don't set a custom ':DefaultModuleMaker'
+so you don't need to normally do anything to configure it.
+
+  dzil new Some::Module
+  # creates ./Some-Module/*
+  # creates ./Some-Module/lib/Some/Module.pm
+
+However, for those who wish to configure this ( or any subclasses ) this is
+presently required:
+
+  [TemplateModule / :DefaultModuleMaker]
+  ; template  = SomeFile.pm
 
 =head1 AUTHOR
 
@@ -96,7 +119,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
