@@ -1,16 +1,17 @@
 package Dist::Zilla::Plugin::UploadToCPAN;
-BEGIN {
-  $Dist::Zilla::Plugin::UploadToCPAN::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::UploadToCPAN::VERSION = '4.300005';
 }
 # ABSTRACT: upload the dist to CPAN
 use Moose;
-with 'Dist::Zilla::Role::Releaser';
+with qw(Dist::Zilla::Role::BeforeRelease Dist::Zilla::Role::Releaser);
 
 use CPAN::Uploader 0.101550; # ua string
 use File::HomeDir;
 use File::Spec;
 use Moose::Util::TypeConstraints;
 use Scalar::Util qw(weaken);
+use Try::Tiny;
 
 use namespace::autoclean;
 
@@ -19,6 +20,7 @@ use namespace::autoclean;
   package
     Dist::Zilla::Plugin::UploadToCPAN::_Uploader;
   use base 'CPAN::Uploader';
+  # Report CPAN::Uploader's version, not ours:
   sub _ua_string { CPAN::Uploader->_ua_string }
 
   sub log {
@@ -52,6 +54,7 @@ sub mvp_aliases {
   return { user => 'username' };
 }
 
+
 has username => (
   is   => 'ro',
   isa  => 'Str',
@@ -59,10 +62,13 @@ has username => (
   required => 1,
   default  => sub {
     my ($self) = @_;
-    return $self->_credential('username') || $self->pause_cfg->{user};
+    return $self->_credential('username')
+        || $self->pause_cfg->{user}
+        || $self->zilla->chrome->prompt_str("PAUSE username: ");
   },
 );
 
+
 has password => (
   is   => 'ro',
   isa  => 'Str',
@@ -70,7 +76,9 @@ has password => (
   required => 1,
   default  => sub {
     my ($self) = @_;
-    return $self->_credential('password') || $self->pause_cfg->{password};
+    return $self->_credential('password')
+        || $self->pause_cfg->{password}
+        || $self->zilla->chrome->prompt_str("PAUSE password (will echo): ");
   },
 );
 
@@ -83,6 +91,7 @@ has pause_cfg_file => (
   },
 );
 
+
 has pause_cfg => (
   is      => 'ro',
   isa     => 'HashRef[Str]',
@@ -103,12 +112,20 @@ has pause_cfg => (
   },
 );
 
+
 has subdir => (
     is        => 'ro',
     isa       => 'Str',
     predicate => 'has_subdir',
 );
 
+
+has upload_uri => (
+  is => 'ro',
+  isa => 'Str',
+  predicate => 'has_upload_uri',
+);
+
 has uploader => (
   is   => 'ro',
   isa  => 'CPAN::Uploader',
@@ -121,6 +138,8 @@ has uploader => (
       password => $self->password,
       ($self->has_subdir
            ? (subdir => $self->subdir) : ()),
+      ($self->has_upload_uri
+           ? (upload_uri => $self->upload_uri) : ()),
     });
 
     $uploader->{'Dist::Zilla'}{plugin} = $self;
@@ -130,6 +149,21 @@ has uploader => (
   }
 );
 
+sub before_release {
+  my $self = shift;
+
+  my $problem;
+  try {
+    for my $attr (qw(username password)) {
+      $problem = $attr;
+      die unless length $self->$attr;
+    }
+    undef $problem;
+  };
+
+  $self->log_fatal(['You need to supply a %s', $problem]) if $problem;
+}
+
 sub release {
   my ($self, $archive) = @_;
 
@@ -137,7 +171,6 @@ sub release {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -149,7 +182,7 @@ Dist::Zilla::Plugin::UploadToCPAN - upload the dist to CPAN
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 SYNOPSIS
 
@@ -170,13 +203,46 @@ C<~/.pause>, in the same format that L<cpan-upload> requires:
   user YOUR-PAUSE-ID
   password YOUR-PAUSE-PASSWORD
 
+If neither configuration exists, it will prompt you to enter your
+username and password during the BeforeRelease phase.  Entering a
+blank username or password will abort the release.
+
+=head1 ATTRIBUTES
+
+=head2 username
+
+This option supplies the user's PAUSE username.  If not supplied, it will be
+looked for in the user's PAUSE configuration.
+
+=head2 password
+
+This option supplies the user's PAUSE password.  If not supplied, it will be
+looked for in the user's PAUSE configuration.
+
+=head2 pause_cfg
+
+This is a hashref of defaults loaded from F<~/.pause> -- this attribute is
+subject to removal in future versions, as the config-loading behavior in
+CPAN::Uploader is improved.
+
+=head2 subdir
+
+If given, this specifies a subdirectory under the user's home directory to
+which to upload.  Using this option is not recommended.
+
+=head2 upload_uri
+
+If given, this specifies an alternate URI for the PAUSE upload form.  By
+default, the default supplied by L<CPAN::Uploader> is used.  Using this option
+is not recommended in most cases.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
