@@ -1,12 +1,14 @@
 package Dist::Zilla::PluginBundle::Filter;
-BEGIN {
-  $Dist::Zilla::PluginBundle::Filter::VERSION = '4.101900';
+{
+  $Dist::Zilla::PluginBundle::Filter::VERSION = '4.300005';
 }
 # ABSTRACT: use another bundle, with some plugins removed
 use Moose;
 use Moose::Autobox;
 with 'Dist::Zilla::Role::PluginBundle';
 
+use namespace::autoclean;
+
 use Dist::Zilla::Util;
 
 
@@ -54,7 +56,6 @@ sub bundle_config {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -66,7 +67,7 @@ Dist::Zilla::PluginBundle::Filter - use another bundle, with some plugins remove
 
 =head1 VERSION
 
-version 4.101900
+version 4.300005
 
 =head1 SYNOPSIS
 
@@ -92,7 +93,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
