@@ -1,15 +1,16 @@
 package Dist::Zilla::Role::AfterBuild;
-BEGIN {
-  $Dist::Zilla::Role::AfterBuild::VERSION = '4.101900';
+{
+  $Dist::Zilla::Role::AfterBuild::VERSION = '4.300005';
 }
 # ABSTRACT: something that runs after building is mostly complete
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'after_build';
 
-no Moose::Role;
 1;
 
 __END__
@@ -21,7 +22,7 @@ Dist::Zilla::Role::AfterBuild - something that runs after building is mostly com
 
 =head1 VERSION
 
-version 4.101900
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -37,7 +38,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
