@@ -1,15 +1,16 @@
 package Dist::Zilla::Role::BeforeMint;
-BEGIN {
-  $Dist::Zilla::Role::BeforeMint::VERSION = '4.200000';
+{
+  $Dist::Zilla::Role::BeforeMint::VERSION = '4.300005';
 }
 # ABSTRACT: something that runs before minting really begins
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'before_mint';
 
-no Moose::Role;
 1;
 
 __END__
@@ -21,7 +22,7 @@ Dist::Zilla::Role::BeforeMint - something that runs before minting really begins
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -34,7 +35,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
