@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::ConfigDumper;
-BEGIN {
-  $Dist::Zilla::Role::ConfigDumper::VERSION = '4.101900';
+{
+  $Dist::Zilla::Role::ConfigDumper::VERSION = '4.300005';
 }
 # ABSTRACT: something that can dump its (public, simplified) configuraiton
 use Moose::Role;
@@ -9,7 +9,6 @@ use namespace::autoclean;
 
 sub dump_config { return {}; }
 
-no Moose::Role;
 1;
 
 __END__
@@ -21,7 +20,7 @@ Dist::Zilla::Role::ConfigDumper - something that can dump its (public, simplifie
 
 =head1 VERSION
 
-version 4.101900
+version 4.300005
 
 =head1 AUTHOR
 
@@ -29,7 +28,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
