@@ -1,11 +1,13 @@
 package Dist::Zilla::Role::ExecFiles;
-BEGIN {
-  $Dist::Zilla::Role::ExecFiles::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::ExecFiles::VERSION = '4.300005';
 }
 # ABSTRACT: something that finds files to install as executables
 use Moose::Role;
 with 'Dist::Zilla::Role::FileFinder';
 
+use namespace::autoclean;
+
 requires 'dir';
 
 sub find_files {
@@ -26,7 +28,7 @@ Dist::Zilla::Role::ExecFiles - something that finds files to install as executab
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 AUTHOR
 
