@@ -1,10 +1,12 @@
 package Dist::Zilla::Role::FileFinderUser;
-BEGIN {
-  $Dist::Zilla::Role::FileFinderUser::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::FileFinderUser::VERSION = '4.300005';
 }
 # ABSTRACT: something that uses FileFinder plugins
 use MooseX::Role::Parameterized;
 
+use namespace::autoclean;
+
 
 
 parameter finder_arg_names => (
@@ -82,7 +84,7 @@ Dist::Zilla::Role::FileFinderUser - something that uses FileFinder plugins
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 DESCRIPTION
 
