@@ -1,18 +1,18 @@
 package Dist::Zilla::Role::FileGatherer;
-BEGIN {
-  $Dist::Zilla::Role::FileGatherer::VERSION = '4.200000';
+{
+  $Dist::Zilla::Role::FileGatherer::VERSION = '4.300005';
 }
 # ABSTRACT: something that gathers files into the distribution
 use Moose::Role;
-with 'Dist::Zilla::Role::Plugin';
-with 'Dist::Zilla::Role::FileInjector';
+with qw/Dist::Zilla::Role::Plugin Dist::Zilla::Role::FileInjector/;
+
+use namespace::autoclean;
 
 use Moose::Autobox;
 
 
 requires 'gather_files';
 
-no Moose::Role;
 1;
 
 __END__
@@ -24,7 +24,7 @@ Dist::Zilla::Role::FileGatherer - something that gathers files into the distribu
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -42,7 +42,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
