@@ -1,10 +1,12 @@
 package Dist::Zilla::Role::FileInjector;
-BEGIN {
-  $Dist::Zilla::Role::FileInjector::VERSION = '4.101900';
+{
+  $Dist::Zilla::Role::FileInjector::VERSION = '4.300005';
 }
 # ABSTRACT: something that can add files to the distribution
 use Moose::Role;
 
+use namespace::autoclean;
+
 use Moose::Autobox;
 
 
@@ -21,7 +23,6 @@ sub add_file {
   $self->zilla->files->push($file);
 }
 
-no Moose::Role;
 1;
 
 __END__
@@ -33,7 +34,7 @@ Dist::Zilla::Role::FileInjector - something that can add files to the distributi
 
 =head1 VERSION
 
-version 4.101900
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -56,7 +57,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
