@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::InstallTool;
-BEGIN {
-  $Dist::Zilla::Role::InstallTool::VERSION = '4.200000';
+{
+  $Dist::Zilla::Role::InstallTool::VERSION = '4.300005';
 }
 # ABSTRACT: something that creates an install program for a dist
 use Moose::Role;
@@ -9,12 +9,13 @@ with qw(
   Dist::Zilla::Role::FileInjector
 );
 
+use namespace::autoclean;
+
 use Moose::Autobox;
 
 
 requires 'setup_installer';
 
-no Moose::Role;
 1;
 
 __END__
@@ -26,7 +27,7 @@ Dist::Zilla::Role::InstallTool - something that creates an install program for a
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -43,7 +44,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
