@@ -1,13 +1,16 @@
 package Dist::Zilla::Role::MetaProvider;
-our $VERSION = '1.100160';
+{
+  $Dist::Zilla::Role::MetaProvider::VERSION = '4.300005';
+}
 # ABSTRACT: something that provides metadata (for META.yml/json)
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'metadata';
 
-no Moose::Role;
 1;
 
 __END__
@@ -19,7 +22,7 @@ Dist::Zilla::Role::MetaProvider - something that provides metadata (for META.yml
 
 =head1 VERSION
 
-version 1.100160
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -29,16 +32,17 @@ This role provides data to merge into the distribution metadata.
 
 =head2 metadata
 
-This method returns a hashref of data to be (deeply) merged together with
-pre-existing metadata.
+This method (which must be provided by classes implementing this role)
+returns a hashref of data to be (deeply) merged together with pre-existing
+metadata.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
