@@ -1,17 +1,18 @@
 package Dist::Zilla::Role::MintingProfile;
-BEGIN {
-  $Dist::Zilla::Role::MintingProfile::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::MintingProfile::VERSION = '4.300005';
 }
 # ABSTRACT: something that can find a minting profile dir
 use Moose::Role;
 
+use namespace::autoclean;
+
 use File::ShareDir;
 use Path::Class;
 
 
 requires 'profile_dir';
 
-no Moose::Role;
 1;
 
 __END__
@@ -23,7 +24,7 @@ Dist::Zilla::Role::MintingProfile - something that can find a minting profile di
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 DESCRIPTION
 
