@@ -1,10 +1,12 @@
 package Dist::Zilla::Role::Stash;
-BEGIN {
-  $Dist::Zilla::Role::Stash::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::Stash::VERSION = '4.300005';
 }
 # ABSTRACT: something that stores options or data for later reference
 use Moose::Role;
 
+use namespace::autoclean;
+
 sub register_component {
   my ($class, $name, $arg, $section) = @_;
 
@@ -34,7 +36,7 @@ Dist::Zilla::Role::Stash - something that stores options or data for later refer
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 AUTHOR
 
