@@ -1,21 +1,26 @@
 use strict;
 use warnings;
 package Dist::Zilla::Util;
-BEGIN {
-  $Dist::Zilla::Util::VERSION = '4.200000';
+{
+  $Dist::Zilla::Util::VERSION = '4.300005';
 }
 # ABSTRACT: random snippets of code that Dist::Zilla wants
 
-use File::HomeDir ();
-use Path::Class;
 use String::RewritePrefix 0.002; # better string context behavior
 
 {
   package
     Dist::Zilla::Util::PEA;
-  use Pod::Eventual 0.091480; # better nonpod/blank events
-  use base 'Pod::Eventual';
-  sub _new  { bless {} => shift; }
+  @Dist::Zilla::Util::PEA::ISA = ('Pod::Eventual');
+  sub _new  {
+    # Load Pod::Eventual only when used (and not yet loaded)
+    unless (exists $INC{'Pod/Eventual.pm'}) {
+      require Pod::Eventual;
+      Pod::Eventual->VERSION(0.091480); # better nonpod/blank events
+    }
+
+    bless {} => shift;
+  }
   sub handle_nonpod {
     my ($self, $event) = @_;
     return if $self->{abstract};
@@ -40,7 +45,7 @@ use String::RewritePrefix 0.002; # better string context behavior
 
     if (
       $event->{type} eq 'text'
-      and $event->{content} =~ /^\S+\s+-+\s+(.+)$/
+      and $event->{content} =~ /^(?:\S+\s+)+?-+\s+(.+)\n$/s
     ) {
       $self->{abstract} = $1;
     }
@@ -49,9 +54,9 @@ use String::RewritePrefix 0.002; # better string context behavior
 
 
 sub abstract_from_file {
-  my ($self, $filename) = @_;
+  my ($self, $file) = @_;
   my $e = Dist::Zilla::Util::PEA->_new;
-  $e->read_file($filename);
+  $e->read_string($file->content);
   return $e->{abstract};
 }
 
@@ -73,12 +78,14 @@ sub expand_config_package_name {
 }
 
 sub _global_config_root {
-  return dir($ENV{DZIL_GLOBAL_CONFIG_ROOT}) if $ENV{DZIL_GLOBAL_CONFIG_ROOT};
+  require Path::Class;
+  return Path::Class::dir($ENV{DZIL_GLOBAL_CONFIG_ROOT}) if $ENV{DZIL_GLOBAL_CONFIG_ROOT};
 
+  require File::HomeDir;
   my $homedir = File::HomeDir->my_home
     or Carp::croak("couldn't determine home directory");
 
-  return dir($homedir)->subdir('.dzil');
+  return Path::Class::dir($homedir)->subdir('.dzil');
 }
 
 1;
@@ -92,7 +99,7 @@ Dist::Zilla::Util - random snippets of code that Dist::Zilla wants
 
 =head1 VERSION
 
-version 4.200000
+version 4.300005
 
 =head1 METHODS
 
@@ -116,7 +123,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
