@@ -1,14 +1,15 @@
 use strict;
 use warnings;
 package Test::DZil;
-BEGIN {
-  $Test::DZil::VERSION = '4.200009';
+{
+  $Test::DZil::VERSION = '4.300005';
 }
 # ABSTRACT: tools for testing Dist::Zilla plugins
 
 use Dist::Zilla::Tester;
 use Params::Util qw(_HASH0);
 use JSON 2;
+use Scalar::Util qw(blessed);
 use Test::Deep ();
 use YAML::Tiny;
 
@@ -31,8 +32,13 @@ sub is_filelist {
   my ($have, $want, $comment) = @_;
 
   my @want = sort @$want;
-  my @have = sort map { my $str = $_; $str =~ s{\\}{/}g; $str } @$have;
+  my @have = sort map { my $str = (blessed $_ and
+                                   $_->DOES('Dist::Zilla::Role::File'))
+                            ? $_->name
+                            : $_;
+                        $str =~ s{\\}{/}g; $str } @$have;
 
+  local $Test::Builder::Level = $Test::Builder::Level + 1;
   Test::More::is_deeply(\@have, \@want, $comment);
 }
 
@@ -43,6 +49,7 @@ sub is_yaml {
   my $have = YAML::Tiny->read_string($yaml)
     or die "Cannot decode YAML";
 
+  local $Test::Builder::Level = $Test::Builder::Level + 1;
   Test::Deep::cmp_deeply($have->[0], $want, $comment);
 }
 
@@ -53,6 +60,7 @@ sub is_json {
   my $have = JSON->new->ascii(1)->decode($json)
     or die "Cannot decode JSON";
 
+  local $Test::Builder::Level = $Test::Builder::Level + 1;
   Test::Deep::cmp_deeply($have, $want, $comment);
 }
 
@@ -133,7 +141,7 @@ Test::DZil - tools for testing Dist::Zilla plugins
 
 =head1 VERSION
 
-version 4.200009
+version 4.300005
 
 =head1 DESCRIPTION
 
@@ -156,7 +164,8 @@ behavior added.
   is_filelist( \@files_we_have, \@files_we_want, $desc );
 
 This test assertion compares two arrayrefs of filenames, taking care of slash
-normalization and sorting.
+normalization and sorting.  C<@files_we_have> may also contain objects that
+do L<Dist::Zilla::Role::File>.
 
 =head2 is_yaml
 
